@@ -4,22 +4,17 @@
  *
  * Copyright (C) 2010 NVIDIA Corporation.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of Version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See Version 2
- * of the GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+ * more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the:
- *
- *           Free Software Foundation, Inc.
- *           59 Temple Place - Suite 330
- *           Boston, MA 02111-1307, USA
- *
+ * along with this program.  If not, see <http://www.gnu.org/licenses>.
  */
 
 #include <gtk/gtk.h>
@@ -532,12 +527,27 @@ static void callback_glasses_paired(GtkObject *object, gpointer arg1,
     Bool ret;
     CtkEventStruct *event_struct;
     char temp[64]; //scratchpad memory used to construct labels.
+    int index;
 
     Ctk3DVisionPro *ctk_3d_vision_pro = CTK_3D_VISION_PRO(user_data);
     AddGlassesDlg  *dlg = ctk_3d_vision_pro->add_glasses_dlg;
     event_struct = (CtkEventStruct *) arg1;
 
     glasses_id = event_struct->value;
+
+    /* It is possible for the user to accidentally try pairing a glass even if 
+     * it is already paired leading to multiple entries. To avoid this, return if 
+     * the glass entry is already present in the local table.
+     */ 
+
+    if (dlg) {
+        for (index = 0; index < dlg->new_glasses; index++) {
+            if (dlg->glasses_info[index]->glasses_id == glasses_id) {
+                return;
+            }        
+        }
+    }
+
     ret = XNVCTRLQueryTargetStringAttribute(NvCtrlGetDisplayPtr(ctk_3d_vision_pro->handle),
                                             NV_CTRL_TARGET_TYPE_3D_VISION_PRO_TRANSCEIVER,
                                             target_id, glasses_id,
@@ -578,6 +588,17 @@ static void callback_glasses_paired(GtkObject *object, gpointer arg1,
         gtk_widget_show_all(GTK_WIDGET(dlg->table.data_table));
     }
 
+    /* This is to avoid multiple entries of a glass's information 
+     * being displayed by nvidia-settings. Return in case the glass 
+     * entry is already present in the HTU table.
+     */
+
+    for (index = 0; index < HTU(0)->num_glasses; index++) {
+        if (HTU(0)->glasses_info[index]->glasses_id == glasses_id) {
+            return;
+        }
+    }
+
     // Add glasses_info into HTU(0)->glasses_info list.
     HTU(0)->glasses_info = realloc(HTU(0)->glasses_info,
                            (HTU(0)->num_glasses + 1) * sizeof(GlassesInfo *));
@@ -1357,18 +1378,17 @@ static ChannelRangeDlg *create_channel_range_change_dlg(Ctk3DVisionPro *ctk_3d_v
 
     switch (range) {
     case SVP_SHORT_RANGE:
-        label = gtk_label_new("You have changed transceiver range to short range (less than 2m.).\n"
+        label = gtk_label_new("You have changed transceiver range to short range (less than 5m.).\n"
                               "Only glasses in this range will be available.\n\n"
                               "Do you want to apply changes?");
         break;
     case SVP_MEDIUM_RANGE:
-        label = gtk_label_new("You have changed transceiver range to medium range (less than 10m.).\n"
+        label = gtk_label_new("You have changed transceiver range to medium range (less than 15m.).\n"
                               "Only glasses in this range will be available.\n\n"
                               "Do you want to apply changes?");
         break;
     case SVP_LONG_RANGE:
-        label = gtk_label_new("You have changed transceiver range to long range.\n"
-                              "Only glasses in this range will be available.\n\n"
+        label = gtk_label_new("You have changed transceiver range to long range.\n\n"
                               "Do you want to apply changes?");
         break;
     }
@@ -1696,9 +1716,9 @@ GtkWidget* ctk_3d_vision_pro_new(NvCtrlAttributeHandle *handle,
 
     hbox = gtk_hbox_new(FALSE, 5);
     menu = gtk_menu_new();
-    add_menu_item(menu, "Short Range (upto 5 meter)");
-    add_menu_item(menu, "Medium Range (upto 15 meter)");
-    add_menu_item(menu, "Long Range (upto 30 meter)");
+    add_menu_item(menu, "Short Range (up to 5 meters)");
+    add_menu_item(menu, "Medium Range (up to 15 meters)");
+    add_menu_item(menu, "Long Range");
     ctk_3d_vision_pro->option_menu = gtk_option_menu_new ();
     gtk_option_menu_set_menu
         (GTK_OPTION_MENU(ctk_3d_vision_pro->option_menu), menu);
@@ -1873,12 +1893,12 @@ GtkTextBuffer *ctk_3d_vision_pro_create_help(GtkTextTagTable *table)
                          "Possible values for transeiver range are 'Short Range' "
                          "'Medium Range' and 'Long Range'.");
     ctk_help_para(b, &i, "Short Range: \n"
-                         "Allows glasses within a 2-meter (6.5-foot) range to "
+                         "Allows glasses within a 5-meter (16.5-foot) range to "
                          "be synced with the hub. This range is typically used "
                          "for sharing 3D simulations and training information "
                          "on a local workstation.");
     ctk_help_para(b, &i, "Medium Range: \n"
-                         "Allows glasses within a 10-meter (32-foot) range to "
+                         "Allows glasses within a 15-meter (49-foot) range to "
                          "be synced with the hub. This range is typically used "
                          "for sharing a presentation with a limited audience or "
                          "interacting with 3D CAD models during a collaborative "
