@@ -4,22 +4,17 @@
  *
  * Copyright (C) 2010 NVIDIA Corporation.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of Version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See Version 2
- * of the GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+ * more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the:
- *
- *           Free Software Foundation, Inc.
- *           59 Temple Place - Suite 330
- *           Boston, MA 02111-1307, USA
- *
+ * along with this program.  If not, see <http://www.gnu.org/licenses>.
  */
 
 #include <gtk/gtk.h>
@@ -70,10 +65,15 @@ void post_color_space_update(CtkColorControls *ctk_color_controls,
 /* help text */
 static const char * __color_controls_help =
 "The Color Controls allow changing the color space and color range "
-"of the display device.  The possible values for Color Space vary "
-"depending on the capabilities of the display device and the GPU, but "
-"may contain \"RGB\", \"YCbCr422\", and \"YCbCr444\".  The possible values "
-"for Color Range are \"Limited\" and \"Full\".";
+"of the display device.";
+
+static const char * __color_space_help =
+"The possible values for Color Space vary depending on the capabilities of "
+"the display device and the GPU, but may contain \"RGB\", \"YCbCr422\", "
+"and \"YCbCr444\".";  
+
+static const char * __color_range_help =
+"The possible values for Color Range are \"Limited\" and \"Full\".";
 
 GType ctk_color_controls_get_type(void)
 {
@@ -110,7 +110,7 @@ GtkWidget* ctk_color_controls_new(NvCtrlAttributeHandle *handle,
 {
     GObject *object;
     CtkColorControls *ctk_color_controls;
-    GtkWidget *frame, *hbox, *label, *eventbox;
+    GtkWidget *frame, *hbox, *label;
     GtkWidget *menu, *table, *menu_item = NULL, *separator;
     ReturnStatus ret1, ret2;
     NVCTRLAttributeValidValuesRec valid1, valid2;
@@ -153,10 +153,7 @@ GtkWidget* ctk_color_controls_new(NvCtrlAttributeHandle *handle,
     ctk_color_controls->color_controls_main = hbox;
 
     frame = gtk_frame_new("Color Controls");
-    eventbox = gtk_event_box_new();
-    gtk_container_add(GTK_CONTAINER(eventbox), frame);
-    gtk_box_pack_start(GTK_BOX(hbox), eventbox, FALSE, FALSE, 0);
-    ctk_config_set_tooltip(ctk_config, eventbox, __color_controls_help);
+    gtk_box_pack_start(GTK_BOX(hbox), frame, FALSE, FALSE, 0);
 
     table = gtk_table_new(1, 6, FALSE);
     gtk_container_add(GTK_CONTAINER(frame), table);
@@ -188,6 +185,9 @@ GtkWidget* ctk_color_controls_new(NvCtrlAttributeHandle *handle,
     gtk_option_menu_set_menu
         (GTK_OPTION_MENU(ctk_color_controls->color_space_menu),
          menu);
+    ctk_config_set_tooltip(ctk_config, 
+                           ctk_color_controls->color_space_menu,
+                           __color_space_help);
 
     /* If dropdown only has one item, disable it */
     if (ctk_color_controls->color_space_table_size > 1) {
@@ -228,6 +228,9 @@ GtkWidget* ctk_color_controls_new(NvCtrlAttributeHandle *handle,
     /* dropdown list for color range */
 
     ctk_color_controls->color_range_menu = gtk_option_menu_new();
+    ctk_config_set_tooltip(ctk_config, 
+                           ctk_color_controls->color_range_menu,
+                           __color_range_help);
 
     g_signal_connect(G_OBJECT(ctk_color_controls->color_range_menu),
                      "changed", G_CALLBACK(color_range_menu_changed),
@@ -333,6 +336,7 @@ void post_color_range_update(CtkColorControls *ctk_color_controls,
         "Limited",  /* NV_CTRL_COLOR_RANGE_LIMITED */
     };
 
+    gtk_widget_set_sensitive(ctk_color_controls->reset_button, TRUE);
     ctk_config_statusbar_message(ctk_color_controls->ctk_config,
                                  "Color Range set to %s for %s.",
                                  color_range_table[color_range],
@@ -349,6 +353,7 @@ void post_color_space_update(CtkColorControls *ctk_color_controls,
         "YCbCr444"   /* NV_CTRL_COLOR_SPACE_YCbCr444 */
     };
 
+    gtk_widget_set_sensitive(ctk_color_controls->reset_button, TRUE);
     ctk_config_statusbar_message(ctk_color_controls->ctk_config,
                                  "Color Space set to %s for %s.",
                                  color_space_table[ctk_color_controls->color_space_table[color_space]],
@@ -386,7 +391,6 @@ static void color_range_menu_changed(GtkOptionMenu *color_range_menu,
 
     /* reflecting the change to statusbar message and the reset button */
     post_color_range_update(ctk_color_controls, color_range);
-    gtk_widget_set_sensitive(ctk_color_controls->reset_button, TRUE);
 
 } /* color_range_menu_changed() */
 
@@ -426,7 +430,6 @@ static void color_space_menu_changed(GtkOptionMenu *color_space_menu,
     /* reflecting the change in color space to other widgets & reset button */
     ctk_color_controls_setup(ctk_color_controls);
     post_color_space_update(ctk_color_controls, color_space);
-    gtk_widget_set_sensitive(ctk_color_controls->reset_button, TRUE);
 
 } /* color_space_menu_changed() */
 
@@ -464,6 +467,12 @@ void add_color_controls_help(CtkColorControls *ctk_color_controls,
 {
     ctk_help_heading(b, i, "Color Controls");
     ctk_help_para(b, i, __color_controls_help);
+
+    ctk_help_term(b, i, "Color Space");
+    ctk_help_para(b, i, __color_space_help);
+
+    ctk_help_term(b, i, "Color Range");
+    ctk_help_para(b, i, __color_range_help);
 } /* add_color_controls_help() */
 
 
@@ -485,6 +494,14 @@ static void color_control_update_received(GtkObject *object, gpointer arg1,
     }
 
     ctk_color_controls_setup(ctk_object);
+    
+    /* update status bar message */
+    switch (event_struct->attribute) {
+    case NV_CTRL_COLOR_RANGE:
+        post_color_range_update(ctk_object, event_struct->value); break;
+    case NV_CTRL_COLOR_SPACE:
+        post_color_space_update(ctk_object, event_struct->value); break;
+    }
 } /* color_control_update_received()  */
 
 
