@@ -4,22 +4,17 @@
  *
  * Copyright (C) 2004 NVIDIA Corporation.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of Version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See Version 2
- * of the GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+ * more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the:
- *
- *           Free Software Foundation, Inc.
- *           59 Temple Place - Suite 330
- *           Boston, MA 02111-1307, USA
- *
+ * along with this program.  If not, see <http://www.gnu.org/licenses>.
  */
 
 /*
@@ -374,8 +369,7 @@ GtkWidget* ctk_display_device_tv_new(NvCtrlAttributeHandle *handle,
                      (gpointer) ctk_display_device_tv);
     
     ctk_config_set_tooltip(ctk_config, ctk_display_device_tv->reset_button,
-                           "The Reset TV Hardware Defaults button restores "
-                           "the TV settings to their default values.");
+                           ctk_help_create_reset_hardware_defaults_text("TV", name));
 
     /* EDID button box */
 
@@ -704,6 +698,7 @@ GtkTextBuffer *ctk_display_device_tv_create_help(GtkTextTagTable *table,
 {
     GtkTextIter i;
     GtkTextBuffer *b;
+    GtkTooltipsData *td;
 
     b = gtk_text_buffer_new(table);
     
@@ -742,7 +737,8 @@ GtkTextBuffer *ctk_display_device_tv_create_help(GtkTextTagTable *table,
         add_acquire_edid_help(b, &i);
     }
     
-    ctk_help_reset_hardware_defaults(b, &i, ctk_display_device_tv->name);
+    td = gtk_tooltips_data_get(GTK_WIDGET(ctk_display_device_tv->reset_button));
+    ctk_help_reset_hardware_defaults (b, &i, td->tip_text);
 
     ctk_help_finish(b);
 
