@@ -4,22 +4,17 @@
  *
  * Copyright (C) 2004 NVIDIA Corporation.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of Version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See Version 2
- * of the GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+ * more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the:
- *
- *           Free Software Foundation, Inc.
- *           59 Temple Place - Suite 330
- *           Boston, MA 02111-1307, USA
- *
+ * along with this program.  If not, see <http://www.gnu.org/licenses>.
  */
 
 #ifndef __CTK_DISPLAYLAYOUT_H__
@@ -178,7 +173,8 @@ typedef struct nvModeRec {
 
 /* Display Device (CRT, DFP, TV, Projector ...) */
 typedef struct nvDisplayRec {
-    struct nvDisplayRec *next;
+    struct nvDisplayRec *next_on_gpu;
+    struct nvDisplayRec *next_in_screen;
     XConfigMonitorPtr    conf_monitor;
 
     struct nvGpuRec    *gpu;            /* GPU the display belongs to */
@@ -221,7 +217,8 @@ typedef struct nvMetaModeRec {
 
 /* X Screen */
 typedef struct nvScreenRec {
-    struct nvScreenRec *next;
+    struct nvScreenRec *next_in_layout;
+
     XConfigScreenPtr conf_screen;
     XConfigDevicePtr conf_device;
 
@@ -237,11 +234,13 @@ typedef struct nvScreenRec {
     CtkEvent *ctk_event;
     int scrnum;
 
+    struct nvLayoutRec *layout; /* Layout this X screen belongs to */
     struct nvGpuRec *gpu;  /* GPU driving this X screen */
 
     int depth;      /* Depth of the screen */
 
     unsigned int displays_mask; /* Display devices on this X screen */
+    nvDisplayPtr displays; /* List of displays using this screen */
     int num_displays; /* # of displays using this screen */
 
     nvMetaModePtr metamodes;     /* List of metamodes */
@@ -276,11 +275,11 @@ typedef struct GvoModeDataRec {
 
 /* GPU (Device) */
 typedef struct nvGpuRec {
-    struct nvGpuRec *next;
+    struct nvGpuRec *next_in_layout; /* List of all GPUs */
 
     NvCtrlAttributeHandle *handle;  /* NV-CONTROL handle to GPU */
     CtkEvent *ctk_event;
-    
+
     struct nvLayoutRec *layout; /* Layout this GPU belongs to */
 
     int max_width;
@@ -289,7 +288,7 @@ typedef struct nvGpuRec {
     Bool allow_depth_30;
 
     char *name;  /* Name of the GPU */
-    
+
     unsigned int connected_displays;  /* Bitmask of connected displays */
 
     gchar *pci_bus_id;
@@ -297,10 +296,7 @@ typedef struct nvGpuRec {
     GvoModeData *gvo_mode_data; /* Information about GVO modes available */
     unsigned int num_gvo_modes;
 
-    nvScreenPtr screens;  /* List of screens this GPU drives */
-    int num_screens;
-
-    nvDisplayPtr displays;  /* List of displays attached to screen */
+    nvDisplayPtr displays; /* Linked list of displays connected to GPU */
     int num_displays;
 
 } nvGpu, *nvGpuPtr;
@@ -314,10 +310,13 @@ typedef struct nvLayoutRec {
 
     NvCtrlAttributeHandle *handle;
 
-    nvGpuPtr gpus;  /* List of GPUs in the layout */
+    nvGpuPtr gpus;  /* Linked list of GPUs (next_in_layout) */
     int num_gpus;
 
-    // Used for drawing the layout.
+    nvScreenPtr screens; /* Linked list of X screens (next_in_layout) */
+    int num_screens;
+
+    /* Used for drawing the layout */
     int dim[4]; /* Bounding box of All X screens (Absolute coords) */
 
     int xinerama_enabled;
@@ -397,11 +396,8 @@ typedef struct _CtkDisplayLayout
 
     /* Double buffering of layout image */
     GdkPixmap *pixmap;
-    int        need_swap;
 
     /* Image information */
-    int        width;           /* Real widget dimensions */
-    int        height;
     int        img_dim[4];      /* Dimensions used to draw in */
     float      scale;
 
@@ -414,7 +410,7 @@ typedef struct _CtkDisplayLayout
     /* Pango layout for strings in layout image */
 
     PangoLayout *pango_layout;
-    
+
     /* List of visible elements in the layout */
     ZNode *Zorder; /* Z ordering of visible elements in layout */
     int    Zcount; /* Count of visible elements in the z order */
@@ -463,18 +459,11 @@ GtkWidget*  ctk_display_layout_new       (NvCtrlAttributeHandle *,
                                           CtkConfig *,
                                           nvLayoutPtr, /* Layout to display */
                                           int,         /* Width of image */
-                                          int,         /* Height of image */
-                                          ctk_display_layout_selected_callback,
-                                          void *selected_callback_data,
-                                          ctk_display_layout_modified_callback,
-                                          void *modified_callback_data
+                                          int          /* Height of image */
                                           );
 
 void ctk_display_layout_update (CtkDisplayLayout *);
 
-void ctk_display_layout_redraw (CtkDisplayLayout *);
-
-
 void ctk_display_layout_set_layout (CtkDisplayLayout *, nvLayoutPtr);
 
 void ctk_display_layout_update_zorder(CtkDisplayLayout *ctk_object);
@@ -526,6 +515,11 @@ void ctk_display_layout_disable_display (CtkDisplayLayout *ctk_object,
 void ctk_display_layout_set_advanced_mode (CtkDisplayLayout *ctk_object,
                                            int advanced_mode);
 
+void ctk_display_layout_register_callbacks(CtkDisplayLayout *ctk_object,
+                                           ctk_display_layout_selected_callback,
+                                           void *selected_callback_data,
+                                           ctk_display_layout_modified_callback,
+                                           void *modified_callback_data);
 
 
 G_END_DECLS
